#ifndef _HERMIT_TARGET_HERMIT_H_
#define _HERMIT_TARGET_HERMIT_H_

#define ARRAY_SIZE(x) (sizeof(x) / sizeof((x)[0]))
#define BIT(x) (1 << x)

#include <io.h>

#define HERM_ERR	0
#define HERM_INFO	1
#define HERM_DEBUG	2

#if !defined(CORE_NAME)
#define CORE_NAME "hermit"
#endif

#define dev_printf(level, args...) \
	hprintf(CORE_NAME ": " args)
#define dev_printf_r(level, args...) \
	hprintf(args)

#define dev_err(args...)	dev_printf(HERM_ERR, args)
#define dev_err_r(args...)	dev_printf_r(HERM_ERR, args)
#define dev_info(args...)	dev_printf(HERM_INFO, args)
#define dev_info_r(args...)	dev_printf_r(HERM_INFO, args)

#if defined(DEBUG)
#define dev_dbg(args...)	dev_printf(HERM_DEBUG, args)
#define dev_dbg_r(args...)	dev_printf_r(HERM_DEBUG, args)
#else
#define dev_dbg(args...)	({ if (0) dev_printf(HERM_DEBUG, args); 0; })
#define dev_dbg_r(args...)	({ if (0) dev_printf_r(HERM_DEBUG, args); 0; })
#endif

#if defined(VERBOSE_DEBUG)
#define dev_vdbg(args...)	dev_printf(HERM_DEBUG, args)
#define dev_vdbg_r(args...)	dev_printf_r(HERM_DEBUG, args)
#else
#define dev_vdbg(args...)	({ if (0) dev_printf(HERM_DEBUG, args); 0; })
#define dev_vdbg_r(args...)	({ if (0) dev_printf_r(HERM_DEBUG, args); 0; })
#endif

#if defined(TRACE_DEBUG)
#define trace() \
	dev_printf(HERM_DEBUG, "%s()\n", __FUNCTION__)
#else
#define trace() \
	({ if (0) dev_printf(HERM_DEBUG, "%s()\n", __FUNCTION__); 0; })
#endif

#endif
